use strict;
use Test::More tests => 9;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var u = 7 + 8;
  var v = 1 - 2;
  var w = 5 -+6;
  var x = 3+4;
};

=for later

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//VariableStatement');
is(scalar @nodes, 4, "4 variable declarations found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//AdditiveOperator');
is(scalar @nodes, 4, "4 variables declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//AdditiveOperator[text()="+"]');
is(scalar @nodes, 2, "2 addition declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//AdditiveOperator[text()="-"]');
is(scalar @nodes, 2, "2 subtraction declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

