use strict;
use Test::More tests => 6;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  /* alert(); */
  
  "This is a string with embedded /* comments */";
  
  /*****
  
  and some multiline comments
  
  *****/
  
  "And still, all is well";
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//String/text()[. = "This is a string with embedded /* comments */"]');
is(scalar @nodes, 1, "1 string with embedded comments found")
  or do { diag $_->toString for ($tree->findnodes('//String/text()'))};

@nodes = $tree->findnodes('//String/text()[. = "And still, all is well"]');
is(scalar @nodes, 1, "1 other string found")
  or do { diag $_->toString for ($tree->findnodes('//String/text()'))};

