use strict;
use Test::More tests => 11;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var a = 1 == 2;
  var b = 3 != 4;
  var c = 5 === 6;
  var d = 7 !== 8;
  var e = 9 < 10 == 11;
};

=for later

??? What should go here?

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//EqualityExpression');
is(scalar @nodes, 5, "5 equality expressions found")
  or do { diag $_->toString for $tree->findnodes('//EqualityExpression' ) };

@nodes = $tree->findnodes('//EqualityExpression[.//Number/text() = 1 and .//Number/text() = 2 and ./EqualityOperator/text() = "=="]');
is(scalar @nodes, 1, "'1 == 2' expression found")
  or do { diag $_->toString for $tree->findnodes('//EqualityExpression') };

@nodes = $tree->findnodes('//EqualityExpression[.//Number/text() = 3 and .//Number/text() = 4 and ./EqualityOperator/text() = "!="]');
is(scalar @nodes, 1, "'3 != 4' expression found")
  or do { diag $_->toString for $tree->findnodes('//EqualityExpression[./EqualityOperator/text() = "!="]') };

@nodes = $tree->findnodes('//EqualityExpression[.//Number/text() = 5 and .//Number/text() = 6 and ./EqualityOperator/text() = "==="]');
is(scalar @nodes, 1, "'5 === 6' expression found")
  or do { diag $_->toString for $tree->findnodes('//EqualityExpression[./EqualityOperator/text() = "==="]') };

@nodes = $tree->findnodes('//EqualityExpression[.//Number/text() = 7 and .//Number/text() = 8 and ./EqualityOperator/text() = "!=="]');
is(scalar @nodes, 1, "'7 !== 8' expression found")
  or do { diag $_->toString for $tree->findnodes('//EqualityExpression[./EqualityOperator/text() = "!=="]') };

@nodes = $tree->findnodes('//EqualityExpression[./RelationalExpression/Number/text() = 10 
                                                and ./Number/text() = 11 and ./EqualityOperator/text() = "=="]');
is(scalar @nodes, 1, "'9 < 10 == 11' expression found")
  or do { diag $_->toString for $tree->findnodes('//EqualityExpression') };


