use strict;
use Test::More tests => 8;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  function b( c ) {
  };

  function d() {
  };

  function e( f,g,h ) {
  };
};

=for later

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//FormalParameterList');
is(scalar @nodes, 3, "3 formal parameter lists found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//FormalParameterList[./FormalParameterList]');
is(scalar @nodes, 0, "FormalParameterList gets flattened correctly")
  or do { diag $_->toString for @nodes;
          diag $tree->toString };

@nodes = $tree->findnodes('//FunctionDeclaration[./NamedFunctionDeclaration/FormalParameterList]');
is(scalar @nodes, 3, "All three formal parameter lists are direct children of a function declaration")
  or do { diag $_->toString for @nodes;
          diag $tree->toString };

