use strict;
use Test::More tests => 10;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var u = 7 * 8;
  var v = 1 / 2;
  var w = 1 % 2;
};

=for later

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//VariableStatement');
is(scalar @nodes, 3, "3 variable declarations found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//MultiplicativeOperator');
is(scalar @nodes, 3, "3 variables declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//MultiplicativeOperator[text()="*"]');
is(scalar @nodes, 1, "1 multiplication declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//MultiplicativeOperator[text()="/"]');
is(scalar @nodes, 1, "1 division declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//MultiplicativeOperator[text()="%"]');
is(scalar @nodes, 1, "1 modulus declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

