use strict;
use Test::More;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;


my @tests = cases( <<'=cut' );
=head2 Class instantiation

  function f() {
      // supposedly returns an object
  };

  // create a new instance:
  var a = new f();

=head2 Constant new expression as function call with assignment (camelCased)

  var b = new Ajax.Updater();

=cut

plan tests => int (@tests / 3*5) + 1;

use_ok('Javascript::PurePerl');
while (my($todo,$name,$JS) = splice @tests, 0, 3) {
    chomp $name;
    my ($parser,$tree);
    eval {
        $parser = Javascript::PurePerl->new();
        $tree = $parser->parse( code => $JS );
    };
    TODO: {
        local $TODO = $todo;
        is($@,"","No crash parsing $name");
        SKIP: {
            isn't($tree, undef, "$name was parsed successfully")
                or skip "Unsuccessful parse", 3;

            my @nodes = $tree->findnodes('/AST');
            is(scalar @nodes, 1, "AST constructed correctly");

            @nodes = $tree->findnodes('/AST/Program');
            is(scalar @nodes, 1, "Program is top level node");

            @nodes = $tree->findnodes('//NewMemberExpression');
            is(scalar @nodes, 1, "1 'new' expression found")
                or do { diag Dumper \@nodes; diag $tree->toString; diag $JS };
	};
    }
};

