use strict;
use Test::More tests => 17;
use Data::Dumper;
use Carp qw(croak);

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var a = 1;
  var b = delete 2;
  var c = void 3;
  var d = typeof 4;

  var e = ++ 1;
  var f = -- 1;
  var g = + 1;
  var h = - 1;
  var i = ~ 1;
  var j = ! 1;

  var k = - - 1;
};

=for later
=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//VariableStatement');
is(scalar @nodes, 11, "11 variable declarations found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//UnaryPrefixOperator');
is(scalar @nodes, 11, "11 unary operations declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="delete"]');
is(scalar @nodes, 1, "1 modulus declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };
@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="void"]');
is(scalar @nodes, 1, "1 modulus declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };
@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="typeof"]');
is(scalar @nodes, 1, "1 modulus declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };


@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="++"]');
is(scalar @nodes, 1, "1 prefix increment declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="--"]');
is(scalar @nodes, 1, "1 prefix decrement declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="+"]');
is(scalar @nodes, 1, "1 unary plus declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="-"]');
is(scalar @nodes, 3, "3 unary minuses declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//UnaryExpression[UnaryPrefixOperator[text()="-"]][UnaryExpression[UnaryPrefixOperator[text()="-"]]]');
is(scalar @nodes, 1, "1 double negative declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="~"]');
is(scalar @nodes, 1, "1 ~ operator declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//UnaryPrefixOperator[text()="!"]');
is(scalar @nodes, 1, "1 '!' operator declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

